@@ -110,7 +110,7 @@ class UIWidget(str, Enum):
     BATTERY_SENSOR = "BatterySensor"
     BIOCLIMATIC_PERGOLA = "BioclimaticPergola"
     CO2_SENSOR = "CO2Sensor"
-    COSENSOR = "COSensor"
+    CO_SENSOR = "COSensor"
     CAR_BUTTON_SENSOR = "CarButtonSensor"
     CAR_LOCK = "CarLock"
     CARD_SWITCH = "CardSwitch"
@@ -139,10 +139,10 @@ class UIWidget(str, Enum):
     DE_DIETRICH_HEATING_CIRCUIT = "DeDietrichHeatingCircuit"
     DE_DIETRICH_MODBUS_GATEWAY = "DeDietrichModbusGateway"
     DE_DIETRICH_SWIMMING_POOL = "DeDietrichSwimmingPool"
-    DIMMER_CIECOLOR_SPACE_XYLIGHT = "DimmerCIEColorSpaceXYLight"
+    DIMMER_CIE_COLOR_SPACE_XY_LIGHT = "DimmerCIEColorSpaceXYLight"
     DIMMER_COLOR_TEMPERATURE_LIGHT = "DimmerColorTemperatureLight"
     DIMMER_EXTERIOR_HEATING = "DimmerExteriorHeating"
-    DIMMER_HUE_SAT_OR_CTLIGHT = "DimmerHueSatOrCTLight"
+    DIMMER_HUE_SAT_OR_CT_LIGHT = "DimmerHueSatOrCTLight"
     DIMMER_HUE_SATURATION_LIGHT = "DimmerHueSaturationLight"
     DIMMER_LIGHT = "DimmerLight"
     DIMMER_ON_OFF = "DimmerOnOff"
